"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAmplifyDeployment = exports.startAmplifyDeployment = exports.createAmplifyBranch = exports.waitJobToSucceed = exports.checkExistingAmplifyBranch = exports.createAmplifyApp = exports.getExistingAmplifyAppId = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var client_amplify_1 = require("@aws-sdk/client-amplify");
/**
 * Check whether the given Amplify app exists.
 * @param appName The Amplify application name.
 * @param client The Amplify SDK client.
 * @returns A Promise that resolves to an app ID string.
 * If an app matching "appName" exists, that app ID will be returned.
 * Otherwise, an undefined variable will be returned.
 */
exports.getExistingAmplifyAppId = function (appName, client) { return __awaiter(void 0, void 0, void 0, function () {
    var nextToken, listAppResponse, existingApp;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, client.send(new client_amplify_1.ListAppsCommand({ nextToken: nextToken }))];
            case 1:
                listAppResponse = _a.sent();
                if (listAppResponse === null || listAppResponse === void 0 ? void 0 : listAppResponse.apps) {
                    existingApp = listAppResponse.apps.find(function (app) { return app.name === appName && app.appId; });
                    if (existingApp && existingApp.appId) {
                        return [2 /*return*/, existingApp.appId];
                    }
                }
                nextToken = listAppResponse === null || listAppResponse === void 0 ? void 0 : listAppResponse.nextToken;
                _a.label = 2;
            case 2:
                if (nextToken) return [3 /*break*/, 0];
                _a.label = 3;
            case 3: 
            /* eslint-enable no-await-in-loop */
            return [2 /*return*/, undefined];
        }
    });
}); };
/**
 * Create an Amplify App and a branch.
 * @param appName The Amplify application name.
 * @param client The Amplify SDK client.
 * @returns A Promise that resolves to an app ID string.
 * If an app created with the input "appName", that app ID will be returned.
 * Otherwise, an error will be thrown.
 * @throws An error with the specific error information why the app fails to be created.
 */
exports.createAmplifyApp = function (appName, client) { return __awaiter(void 0, void 0, void 0, function () {
    var createAppResponse, error_1;
    var _a;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                _b.trys.push([0, 2, , 3]);
                return [4 /*yield*/, client.send(new client_amplify_1.CreateAppCommand({ name: appName }))];
            case 1:
                createAppResponse = _b.sent();
                return [2 /*return*/, (_a = createAppResponse.app) === null || _a === void 0 ? void 0 : _a.appId];
            case 2:
                error_1 = _b.sent();
                throw new Error("The app " + appName + " could not be created due to: " + error_1.message);
            case 3: return [2 /*return*/];
        }
    });
}); };
/**
 * Check whether the given Amplify branch exists in the Amplify app.
 * @param appId The Amplify application Id.
 * @param branchName The Amplify environment branch name.
 * @param client The Amplify SDK Client
 * @returns A Promise that resolves to a boolean variable.
 * If the branch with the input "branchName" exists, it will return true.
 * Otherwise, it will return false;
 */
exports.checkExistingAmplifyBranch = function (appId, branchName, client) { return __awaiter(void 0, void 0, void 0, function () {
    var getBranchResponse, error_2;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 2, , 3]);
                return [4 /*yield*/, client.send(new client_amplify_1.GetBranchCommand({ appId: appId, branchName: branchName }))];
            case 1:
                getBranchResponse = _a.sent();
                if (getBranchResponse.branch) {
                    return [2 /*return*/, true];
                }
                return [2 /*return*/, false];
            case 2:
                error_2 = _a.sent();
                return [2 /*return*/, false];
            case 3: return [2 /*return*/];
        }
    });
}); };
/**
 * wait the submitted job to succeed.
 * @param job The job of Amplify deployment.
 * @param client The Amplify SDK Client.
 * @returns A Promise that resolves when getting a response by given jobId.
 * Otherwise, it will reject when it fails to get job.
 * @throws An error if it failed to get the job.
 */
exports.waitJobToSucceed = function (appId, branchName, jobId, client) { return __awaiter(void 0, void 0, void 0, function () {
    var processing, getResponse, jobSummary;
    var _a;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                processing = true;
                _b.label = 1;
            case 1:
                if (!processing) return [3 /*break*/, 4];
                return [4 /*yield*/, client.send(new client_amplify_1.GetJobCommand({ appId: appId, branchName: branchName, jobId: jobId }))];
            case 2:
                getResponse = _b.sent();
                jobSummary = (_a = getResponse.job) === null || _a === void 0 ? void 0 : _a.summary;
                if ((jobSummary === null || jobSummary === void 0 ? void 0 : jobSummary.status) === 'FAILED') {
                    processing = false;
                    throw new Error("Job failed." + JSON.stringify(jobSummary));
                }
                if ((jobSummary === null || jobSummary === void 0 ? void 0 : jobSummary.status) === 'SUCCEED') {
                    processing = false;
                }
                return [4 /*yield*/, new Promise(function (resolve) {
                        setTimeout(resolve, 1000 * 3);
                    })];
            case 3:
                _b.sent();
                return [3 /*break*/, 1];
            case 4: return [2 /*return*/];
        }
    });
}); };
/**
 * The wrapper of Amplify CreateBranchCommend.
 * @param appId The Amplify application ID.
 * @param branchName The Amplify Environment Name.
 * @param client The Amplify SDK Client.
 * @return A Promise that resolves when the Amplify branch is created.
 */
exports.createAmplifyBranch = function (appId, branchName, client) { return __awaiter(void 0, void 0, void 0, function () { return __generator(this, function (_a) {
    return [2 /*return*/, client.send(new client_amplify_1.CreateBranchCommand({ appId: appId, branchName: branchName }))];
}); }); };
/**
 * The wrapper of Amplify StartAmplifyDeployment.
 * @param appId The Amplify application ID.
 * @param branchName The Amplify Environment Name.
 * @param jobId The Amplify Application job ID
 * @param client The Amplify SDK Client.
 * @returns A Promise that resolves when the amplify deployment is started.
 */
exports.startAmplifyDeployment = function (appId, branchName, jobId, client) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        return [2 /*return*/, client.send(new client_amplify_1.StartDeploymentCommand({
                appId: appId,
                branchName: branchName,
                jobId: jobId,
            }))];
    });
}); };
/**
 * The wrapper of Amplify CreateDeploymentCommand.
 * @param appId The Amplify application ID.
 * @param branchName The Amplify Environment Name.
 * @param client The Amplify SDK Client.
 * @returns A Promise that resolves when the amplify deployment is created.
 */
exports.createAmplifyDeployment = function (appId, branchName, client) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        return [2 /*return*/, client.send(new client_amplify_1.CreateDeploymentCommand({
                appId: appId,
                branchName: branchName,
            }))];
    });
}); };
//# sourceMappingURL=amplifyUtils.js.map