"use strict";
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerEditorPlugin = void 0;
var react_1 = __importDefault(require("react"));
var toolbar_1 = require("./toolbar");
var preferences_1 = require("./preferences");
/**
 * Registers the plugin by returning the IPlugin content.
 * @param editor defines the main reference to the editor.
 * @returns an object that implements IPlugin
 */
exports.registerEditorPlugin = function (editor) { return ({
    /**
     * Defines the list of all toolbar elements to add when the plugin has been loaded.
     */
    toolbar: [
        {
            buttonLabel: 'AWS Amplify Publisher Tools',
            buttonIcon: 'export',
            content: react_1.default.createElement(toolbar_1.AmplifyPublisherToolbar, { editor: editor }),
        },
    ],
    /**
     * This will return a dictionary that will be saved as JSON
     * in the workspace file. This will be typically used to store preferences of the plugin
     * work a given workspace and not globally.
     * The preferences will be saved in the .editorworkspace file each time the user
     * saves the project.
     */
    getWorkspacePreferences: function () { return preferences_1.getAmplifyPublishingPreferences(); },
    /**
     * When the plugin is loaded, this function will be called,
     * giving the plain JSON representation of the user's preferences for
     * the current plugin.
     */
    setWorkspacePreferences: function (preferences) {
        preferences_1.setAmplifyPublishingPreferences(preferences);
    },
}); };
//# sourceMappingURL=index.js.map