"use strict";
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultDomainForBranch = exports.zipArtifacts = exports.httpPutFile = void 0;
var fs_extra_1 = __importDefault(require("fs-extra"));
var archiver_promise_1 = __importDefault(require("archiver-promise"));
var path_1 = __importDefault(require("path"));
// eslint-disable-next-line import/no-unresolved
var babylonjs_editor_1 = require("babylonjs-editor");
/**
 * Put file into a HTTP URL request body.
 * @param filePath the path of the file.
 * @param url the url string.
 * @returns A Promise that resolves when the file upload is complete.
 * @throws Can throw the same errors thrown by fetch().
 * See [fetch documentation]{@link https://developer.mozilla.org/en-US/docs/Web/API/fetch} for details.
 */
function httpPutFile(filePath, url) {
    return __awaiter(this, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, fetch(url, {
                        method: 'PUT',
                        body: fs_extra_1.default.readFileSync(filePath),
                    })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.httpPutFile = httpPutFile;
/**
 * Compress files to a zip file.
 * @param sourceDir the path of the source directory.
 * @param destFilePath the path of the destination file.
 * @returns A Promise object that resolves the zip file path.
 * Otherwise, it will reject if no file exists or any errors appear
 * and throw error message to the upper level.
 * @throws An error once the path does not exist.
 */
function zipFile(sourceDir, destFilePath) {
    return __awaiter(this, void 0, void 0, function () {
        var archive;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!fs_extra_1.default.pathExistsSync(sourceDir)) {
                        throw new Error("Please ensure the build artifacts path " + sourceDir + " exists.");
                    }
                    archive = archiver_promise_1.default(destFilePath, { store: true });
                    return [4 /*yield*/, archive.directory(sourceDir, false)];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, archive.finalize()];
                case 2:
                    _a.sent();
                    return [2 /*return*/, destFilePath];
            }
        });
    });
}
/**
 * Compress the files needed to be host on the server.
 * @param folderPrefix the prefix of the folder's name.
 * @returns A Promise object that resolves the zip file path.
 * @throws An error if it fails to get WorkSpace DirPath or it does not exist.
 */
function zipArtifacts(folderPrefix) {
    return __awaiter(this, void 0, void 0, function () {
        var tmpDir, workSpaceDirPath, now, tmpDirScenes, scenesFolder, tmpDirDist, distFolder, tempIndexHTML, indexHTML, zipFilePath;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    workSpaceDirPath = babylonjs_editor_1.WorkSpace.DirPath;
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, , 3, 4]);
                    if (workSpaceDirPath !== null && fs_extra_1.default.existsSync(workSpaceDirPath)) {
                        now = new Date();
                        tmpDir = fs_extra_1.default.mkdtempSync(path_1.default.join(workSpaceDirPath, "" + folderPrefix + now.getTime()));
                        tmpDirScenes = path_1.default.join(tmpDir, 'scenes');
                        scenesFolder = path_1.default.join(workSpaceDirPath, 'scenes');
                        fs_extra_1.default.copySync(scenesFolder, tmpDirScenes);
                        tmpDirDist = path_1.default.join(tmpDir, 'dist');
                        distFolder = path_1.default.join(workSpaceDirPath, 'dist');
                        fs_extra_1.default.copySync(distFolder, tmpDirDist);
                        tempIndexHTML = path_1.default.join(tmpDir, 'index.html');
                        indexHTML = path_1.default.join(workSpaceDirPath, 'index.html');
                        fs_extra_1.default.copyFileSync(indexHTML, tempIndexHTML);
                    }
                    else {
                        throw new Error("Cannot get WorkSpace directory " + workSpaceDirPath + ", or it does not exist.");
                    }
                    zipFilePath = tmpDir + ".zip";
                    return [4 /*yield*/, zipFile(tmpDir, zipFilePath)];
                case 2: return [2 /*return*/, _a.sent()];
                case 3:
                    try {
                        if (tmpDir) {
                            fs_extra_1.default.rmdirSync(tmpDir, { recursive: true });
                        }
                    }
                    catch (error) {
                        console.error("An error has occurred while removing the temp folder at " + tmpDir + ". Please remove it manually. " + error);
                    }
                    return [7 /*endfinally*/];
                case 4: return [2 /*return*/];
            }
        });
    });
}
exports.zipArtifacts = zipArtifacts;
/**
 * Get the default Domain URL for the given appId and branch.
 * @param appId The Amplify application Id.
 * @param branch The Amplify environment branch name.
 * @returns The domain url for the given appId with the branch.
 */
function getDefaultDomainForBranch(appId, branch) {
    return "https://" + branch + "." + appId + ".amplifyapp.com";
}
exports.getDefaultDomainForBranch = getDefaultDomainForBranch;
//# sourceMappingURL=utils.js.map